@@ -16,7 +16,7 @@ var searchData=
   ['officeinstallationdirectories_2eidl_13',['OfficeInstallationDirectories.idl',['../OfficeInstallationDirectories_8idl.html',1,'']]],
   ['officerestartmanager_2eidl_14',['OfficeRestartManager.idl',['../OfficeRestartManager_8idl.html',1,'']]],
   ['offlinebackend_2eidl_15',['OfflineBackend.idl',['../OfflineBackend_8idl.html',1,'']]],
-  ['ole2shape_2eidl_16',['ole2shape.idl',['../drawing_2OLE2Shape_8idl.html',1,'(Global Namespace)'],['../presentation_2OLE2Shape_8idl.html',1,'(Global Namespace)']]],
+  ['ole2shape_2eidl_16',['OLE2Shape.idl',['../drawing_2OLE2Shape_8idl.html',1,'(Global Namespace)'],['../presentation_2OLE2Shape_8idl.html',1,'(Global Namespace)']]],
   ['oleapplicationregistration_2eidl_17',['OleApplicationRegistration.idl',['../OleApplicationRegistration_8idl.html',1,'']]],
   ['olebridgesupplier_2eidl_18',['OleBridgeSupplier.idl',['../OleBridgeSupplier_8idl.html',1,'']]],
   ['olebridgesupplier2_2eidl_19',['OleBridgeSupplier2.idl',['../OleBridgeSupplier2_8idl.html',1,'']]],
