@@ -1,5 +1,5 @@
 var servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1BindableControlModel =
 [
-    [ "FormControlModel", "servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1BindableControlModel.html#ac6f7a0c00d2607c9e12b50239e9482a1", null ],
+    [ "com::sun::star::form::FormControlModel", "servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1BindableControlModel.html#ac6f7a0c00d2607c9e12b50239e9482a1", null ],
     [ "XBindableValue", "servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1BindableControlModel.html#abc74ca201f87eb098f1fa1b9aaa41803", null ]
 ];
\ No newline at end of file
