@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings =
 [
-    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
+    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
     [ "Align", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a7645c0b1b02b3ec44634fa3ab7e70bb1", null ],
     [ "ControlDefault", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a67bb04a3f9a3ff0cd0c92a25f3f4c12e", null ],
     [ "ControlModel", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a1faacb9b3134e41b40313cda5495b9dc", null ],
